%define anolis_release 4

Summary:        Digest - Modules that calculate message digests
Name:           perl-Digest
Version:        1.20
Release:        %{anolis_release}%{?dist}
License:        GPL+ or Artistic
URL:            https://metacpan.org/release/Digest
Source0:        https://cpan.metacpan.org/authors/id/T/TO/TODDR/Digest-%{version}.tar.gz

BuildArch:      noarch
BuildRequires:  coreutils make
BuildRequires:  perl-generators perl-interpreter
BuildRequires:  perl(:VERSION) >= 5.6 perl(Config) perl(ExtUtils::MakeMaker) >= 6.76
BuildRequires:  perl(strict) perl(warnings)
# requires for runtime:
BuildRequires:  perl(Carp) perl(Exporter) perl(MIME::Base64)
# requires for tests:
BuildRequires:  perl(File::Temp) perl(lib) perl(Test::More) >= 0.47 perl(MIME::Base64)

%global __provides_exclude_from %{?__provides_exclude_from:%__provides_exclude_from|}^%{_libexecdir}

%description
The Digest:: modules calculate digests, also called "fingerprints" or
"hashes", of some data, called a message. The digest is (usually) some
small/fixed size string. The actual size of the digest depends of the
algorithm used. The message is simply a sequence of arbitrary bytes or bits.

An important property of the digest algorithms is that the digest is likely
to change if the message change in some way. Another property is that digest
functions are one-way functions, that is it should be hard to find a message
that correspond to some given digest. Algorithms differ in how "likely" and
how "hard", as well as how efficient they are to compute.

Note that the properties of the algorithms change over time, as the algorithms
are analyzed and machines grow faster. If your application for instance depends
on it being "impossible" to generate the same digest for a different message
it is wise to make it easy to plug in stronger algorithms as the one used grow
weaker. Using the interface documented here should make it easy to change
algorithms later.

All Digest:: modules provide the same programming interface. A functional
interface for simple use, as well as an object oriented interface that can
handle messages of arbitrary length and which can read files directly.

%package tests
Summary: Tests for %{name}
Requires: %{name} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires: perl-Test-Harness

%description tests
The %{name}-tests package contains tests for %{name}. You can execute them
with "%{_libexecdir}/%{name}/test".

%package doc
Summary:        Doc files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n Digest-%{version}

# Help generators to recognize Perl scripts
for F in t/*.t; do
    perl -i -MConfig -ple 'print $Config{startperl} if $. == 1 && !s{\A#!.*perl\b}{$Config{startperl}}' "$F"
    chmod +x "$F"
done

%build
perl Makefile.PL INSTALLDIRS=vendor NO_PACKLIST=1 NO_PERLLOCAL=1
%make_build

%install
%make_install
%{_fixperms} %{buildroot}/*

# Install tests
mkdir -p %{buildroot}%{_libexecdir}/%{name}
cp -a t %{buildroot}%{_libexecdir}/%{name}
cat > %{buildroot}%{_libexecdir}/%{name}/test << 'EOF'
#!/bin/sh
cd %{_libexecdir}/%{name}
exec prove -I . -j "$(getconf _NPROCESSORS_ONLN)"
EOF

chmod +x %{buildroot}%{_libexecdir}/%{name}/test

%check
export HARNESS_OPTIONS=j$(perl -e 'if ($ARGV[0] =~ /.*-j([0-9][0-9]*).*/) {print $1} else {print 1}' -- '%{?_smp_mflags}')
make test

%files
%{perl_vendorlib}/*
%{_mandir}/man3/*

%files tests
%{_libexecdir}/%{name}

%files doc
%doc Changes digest-bench README

%changelog
* Thu Apr 13 2023 Kun(llfl) <llfl@linux.alibaba.com> - 1.20-4
- optimize spec file

* Tue Feb 07 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.20-3
- remove versioned MODULE_COMPAT_ requires

* Mon Jan 30 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.20-2
- rebuild with perl 5.36.0

* Thu Mar 10 2022 Su Lifan <su-lifan@linux.alibaba.com> - 1.20-1
- Initial packaging for Anolis OS 23
